@@ -27,7 +27,7 @@
         </tr>
         <tr>
           <td>OpenBSD</td>
-          <td>2.16</td>
+          <td>2.16/2.17</td>
           <td><i>monolithic kernel</i> / <i>modules not supported</i></td>
         </tr>
         <tr>
@@ -42,6 +42,21 @@
   <tr>
     <td>&nbsp;</td>
   </tr>
+  <tr>
+    <td align="right" valign="top" class="section"><b>To 2.17 (June 19
+      2006)&nbsp;&gt;</td>
+    <td valign="top">
+
+      <ul type="clog">
+        <li class="plus">Support for Linux 2.6.17, FreeBSD 6.1, OpenBSD 3.9</li>
+        <li class="plus">added missing <tt>-fprofile-arcs -ftest-coverage</tt> to <tt>LDFLAGS</tt> for <tt>PROF=1</tt></li>
+      </ul>
+
+    </td>
+  </tr>
+  <tr>
+    <td>&nbsp;</td>
+  </tr>
   <tr>
     <td align="right" valign="top" class="section"><b>To 2.16 (April 01
       2006)&nbsp;&gt;</td>
