@@ -124,8 +124,7 @@
           <td valign="top">Shows the timestamp at the top right corner. Note
           that this might not work with all terminals, because for one, not all
           support it, and second, the escape code is currently hardcoded (no
-          terminfo use), so it might just break on the next terminal you
-          try.</p>
+          terminfo use), so it may break on some strange terminal types.</p>
 
           <p class="block"><tt>-t</tt> will use "<tt>%H:%M:%S</tt>" as the
           format, while <tt>-tt</tt> (or <tt>-t -t</tt>) uses "<tt>%d.%m
@@ -187,11 +186,11 @@
           <td valign="top">Increase playing speed by 0.10</td>
         </tr>
         <tr>
-          <td valign="top"><tt>6</tt></td>
+          <td valign="top">(keypad) <tt>6</tt></td>
           <td valign="top">Skip forward 10 seconds</td>
         </tr>
         <tr>
-          <td valign="top"><tt>9</tt></td>
+          <td valign="top">(keypad) <tt>9</tt></td>
           <td valign="top">Skip forward 60 seconds</td>
         </tr>
         <tr>
@@ -201,7 +200,8 @@
         <tr>
           <td valign="top"><tt>e</tt></td>
           <td valign="top">Toggle ECHO mode, i.e. show <tt>EVT_READ</tt>
-            packets (keypresses) as well, rather than just screen output.</td>
+            packets (keypresses) as well, rather than just screen output. This
+            is useful for echo-less (mostly password) prompts.</td>
         </tr>
       </table>
 
