@@ -8,11 +8,12 @@
       data directly to another host without logging it on the one where it was
       captured. This is commonly referred to as "network logging".</p>
 
-      <p class="block"><i>Note right at the start:</i> It is not very useful to
-      transfer between different operating systems, because each has completely
-      different major numbers for different ttys, so running <i>rpld</i> on
-      Linux and feeding it input from a FreeBSD capturer will yield wrong
-      terminal names.</p>
+      <p class="block"><i>Note:</i> This does not work reliably (i.e. you get
+      wrong device names) when the major/minor numbers are different between
+      two hosts! Network logging is currently only of use between Linux where
+      tty classes have the same major number. Another constraint is that the
+      tty node must also exist on the destination system, which is not always
+      the case with dynamic /dev directories (either by devfs or udev).</p>
 
     </td>
   </tr>
