@@ -1,7 +1,7 @@
 <?php include_once("_header.php"); ?>
   <tr>
 
-    <td align="right" valign="top" class="section"><b>Hosters&gt;</b></td>
+    <td align="right" valign="top" class="section"><b>Hosters&nbsp;&gt;</b></td>
 
     <td valign="top">
 
@@ -38,21 +38,6 @@
   <tr>
     <td>&nbsp;</td>
   </tr>
-  <tr>
-
-    <td align="right" valign="top" class="section"><b>Interactive
-    help&nbsp;&gt;</b></td>
-
-    <td valign="top">
-
-      <p class="block">There is an IRC channel <tt>#ttyrpld</tt> on
-      <tt>irc.freenode.net</tt>. It allows for faster replying to questions and
-      re-replying to answers. Of course, only as long as we are online.  If it
-      is a bug report, <i>please</i> put it on the bug tracker for archiving
-      purposes.</p>
-
-    </td>
-  </tr>
   <tr>
     <td>&nbsp;</td>
   </tr>
@@ -63,8 +48,7 @@
 
     <td valign="top">
 
-      <p class="block"><i>"There's more than one way to do it..."</i>, so here
-      is the 3rd option of getting in contact: <a
+      <p class="block">Another option of getting in contact: <a
       href="http://sourceforge.net/mail/?group_id=120202"
       target="_blank">Mailing lists</a>.</p>
 
