@@ -1,25 +1,33 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 include/rdsh.h - Shared definitions for RPLD/INFO/RPLINFO
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2006
-  -- License restrictions apply (GPL v2)
+  Copyright © Jan Engelhardt <jengelh [at] gmx de>, 2004 - 2006
 
-  This file is part of ttyrpld.
-  ttyrpld is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; however ONLY version 2 of the License.
+  Redistribution and use in source and binary forms, with or without
+  modification, are permitted provided that the following conditions are met:
 
-  ttyrpld is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details.
+  1. Redistributions of source code must retain the above copyright notice,
+     this list of conditions and the following disclaimer.
+  2. Redistributions in binary form must reproduce the above copyright notice,
+     this list of conditions and the following disclaimer in the documentation
+     and/or other materials provided with the distribution.
+  3. Redistributions of modified code that are made available only in binary
+     form require sending a description to the ttyrpld project maintainer on
+     what has been changed.
+  4. Neither the names of the above-listed copyright holders nor the names of
+     any contributors may be used to endorse or promote products derived from
+     this software without specific prior written permission.
 
-  You should have received a copy of the GNU General Public License
-  along with this program kit; if not, write to:
-  Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
-  Boston, MA  02110-1301  USA
-
-  -- For details, see the file named "LICENSE.GPL2"
+  NO WARRANTY. THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
+  CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
+  NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTIBILITY AND FITNESS FOR A
+  PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR
+  CONTRIBUTORS BE LIABLE FOR SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
 =============================================================================*/
 #ifndef TTYRPLD_RDSH_H
 #define TTYRPLD_RDSH_H 1
@@ -28,10 +36,10 @@ include/rdsh.h - Shared definitions for RPLD/INFO/RPLINFO
 #include <pthread.h>
 #include "rpl_stdint.h"
 #include <libHX.h>
-#if !defined(_LIBHX_H) || _LIBHX_H < 20051203
+#if !defined(_LIBHX_H) || _LIBHX_H < 20060225
 #    error ----------------------------------------
 #    error You need a newer version of libHX
-#    error (at least 1.7.3)
+#    error (at least 1.8.0)
 #    error http:/jengelh.hopto.org/coding/libHX.php
 #    error ----------------------------------------
 #endif
