@@ -1,25 +1,25 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 user/infod.c - INFO socket for RPLD
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2006
-  -- License restrictions apply (GPL v2)
+  Copyright © Jan Engelhardt <jengelh [at] gmx de>, 2004 - 2006
+  -- License restrictions apply (LGPL v2.1)
 
   This file is part of ttyrpld.
   ttyrpld is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; however ONLY version 2 of the License.
+  under the terms of the GNU Lesser General Public License as published
+  by the Free Software Foundation; however ONLY version 2 of the License.
 
   ttyrpld is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details.
+  Lesser General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program kit; if not, write to:
+  You should have received a copy of the GNU Lesser General Public
+  License along with this program kit; if not, write to:
   Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
   Boston, MA  02110-1301  USA
 
-  -- For details, see the file named "LICENSE.GPL2"
+  -- For details, see the file named "LICENSE.LGPL2"
 =============================================================================*/
 #include <sys/types.h>
 #include <sys/socket.h>
@@ -99,12 +99,12 @@ static void *client_thread(void *arg) {
         static const uint32_t zero = 0;
         unsigned char req;
         uint32_t gint;
-        int eax = 0;
+        int ret = 0;
 
-        eax |= !RECEIVE_FULL(fd, &req, sizeof(unsigned char));
-        eax |= !RECEIVE_FULL(fd, &gint, sizeof(gint));
+        ret |= !RECEIVE_FULL(fd, &req, sizeof(unsigned char));
+        ret |= !RECEIVE_FULL(fd, &gint, sizeof(gint));
         SWAB1(&gint);
-        if(eax || req == IFP_NONE)
+        if(ret || req == IFP_NONE)
             break;
 
         switch(req) {
@@ -149,6 +149,8 @@ clthr__exit:
 #    define ARCH "FreeBSD"
 #elif defined(__OpenBSD__)
 #    define ARCH "OpenBSD"
+#elif defined(__NetBSD__)
+#    define ARCH "NetBSD"
 #else
 #    define ARCH "Other"
 #endif
@@ -157,7 +159,7 @@ static void getinfo_text(uint32_t dev, int fd) {
     pthread_mutex_lock(&Ttys_lock);
     if(dev == 0) {
         // No device given, send info about RPLD and all ttys
-        struct HXbtree_node *nd;
+        const struct HXbtree_node *nd;
         struct HXbtrav *travp;
 
         skprintf(fd,
@@ -196,7 +198,7 @@ static void getinfo(uint32_t dev, int fd) {
     pthread_mutex_lock(&Ttys_lock);
     if(dev == 0) {
         // No device given, send info about RPLD and all ttys
-        struct HXbtree_node *nd;
+        const struct HXbtree_node *nd;
         struct HXbtrav *travp;
 
         skprintf(fd, "ttyrpld " TTYRPLD_VERSION "\n" "format 3\n"
@@ -242,7 +244,7 @@ static void zero_counters(uint32_t dev) {
     pthread_mutex_lock(&Ttys_lock);
     if(dev == 0) {
         struct HXbtrav *travp = HXbtrav_init(Ttys, NULL);
-        struct HXbtree_node *nd;
+        const struct HXbtree_node *nd;
 
         while((nd = HXbtraverse(travp)) != NULL) {
             struct tty *tty = nd->data;
