@@ -1,26 +1,26 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 user/lib.c - Shared functions for user-space apps
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2006
+  Copyright © Jan Engelhardt <jengelh [at] gmx de>, 2004 - 2006
   Copyright © Nguyen Anh Quynh <aquynh [at] gmail com>, 2005
-  -- License restrictions apply (GPL v2)
+  -- License restrictions apply (LGPL v2.1)
 
   This file is part of ttyrpld.
   ttyrpld is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; however ONLY version 2 of the License.
+  under the terms of the GNU Lesser General Public License as published
+  by the Free Software Foundation; however ONLY version 2 of the License.
 
   ttyrpld is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details.
+  Lesser General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program kit; if not, write to:
+  You should have received a copy of the GNU Lesser General Public
+  License along with this program kit; if not, write to:
   Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
   Boston, MA  02110-1301  USA
 
-  -- For details, see the file named "LICENSE.GPL2"
+  -- For details, see the file named "LICENSE.LGPL2"
 =============================================================================*/
 #include <sys/ioctl.h>
 #include <sys/stat.h>
@@ -45,7 +45,7 @@ void load_locale(const char *exe) {
 
     if(strchr(exe, '/') != NULL) {
         hmc_t *base = hmc_sinit(exe), *de;
-        hmc_trunc(base, HX_strrcspn(base, "/"));
+        hmc_trunc(&base, HX_strrcspn(base, "/"));
         hmc_strcat(&base, "/locale");
         de = hmc_dup(base);
         hmc_strcat(&de, "/de/LC_MESSAGES/ttyrpld.mo");
@@ -103,7 +103,7 @@ off_t G_skip(int fd, off_t offset, int do_wait) {
     size_t rem = offset;
     char buf[4096];
 
-#if (defined(__FreeBSD__) || defined(__OpenBSD__))
+#if (defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__))
     size_t eax = 0;
     if(D_IOCTL(fd, RPL_IOC_IDENTIFY, &eax) && eax == 0xC0FFEE) {
         /* BSD does not have lseek() for device files.
