@@ -84,7 +84,7 @@ static ssize_t read_waitfm(int, void *, size_t, const struct pctrl_info *);
 static int seek_to_end(int, const struct pctrl_info *);
 static int usleep_ovcorr(struct timeval *, long *);
 static void tv_delta(const struct timeval *, const struct timeval *,
- struct timeval *);
+    struct timeval *);
 static inline unsigned long long tv2usec(const struct timeval *);
 static inline void usec2tv(unsigned long long, struct timeval *);
 
@@ -331,7 +331,7 @@ static unsigned long calc_ovcorr(unsigned long ad, int rd) {
         nanosleep(&s, NULL);
         gettimeofday(&stop, NULL);
         av += MICROSECOND * (stop.tv_sec - start.tv_sec) +
-         stop.tv_usec - start.tv_usec;
+              stop.tv_usec - start.tv_usec;
     }
 
     av /= rd;
@@ -675,7 +675,8 @@ static int usleep_ovcorr(struct timeval *req, long *skew) {
 }
 
 static void tv_delta(const struct timeval *past, const struct timeval *now,
- struct timeval *dest) {
+ struct timeval *dest)
+{
     /* Calculates the time difference between "past" and "now" and stores the
     result in "dest". All parameters in µs. */
     unsigned long sec = now->tv_sec - past->tv_sec;
