@@ -1,25 +1,25 @@
 /*=============================================================================
 ttyrpld - TTY replay daemon
 user/rplctl.c - INFOD client
-  Copyright © Jan Engelhardt <jengelh [at] linux01 gwdg de>, 2004 - 2006
-  -- License restrictions apply (GPL v2)
+  Copyright © Jan Engelhardt <jengelh [at] gmx de>, 2004 - 2006
+  -- License restrictions apply (LGPL v2.1)
 
   This file is part of ttyrpld.
   ttyrpld is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; however ONLY version 2 of the License.
+  under the terms of the GNU Lesser General Public License as published
+  by the Free Software Foundation; however ONLY version 2 of the License.
 
   ttyrpld is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-  General Public License for more details.
+  Lesser General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program kit; if not, write to:
+  You should have received a copy of the GNU Lesser General Public
+  License along with this program kit; if not, write to:
   Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
   Boston, MA  02110-1301  USA
 
-  -- For details, see the file named "LICENSE.GPL2"
+  -- For details, see the file named "LICENSE.LGPL2"
 =============================================================================*/
 #include <sys/types.h>
 #include <sys/select.h>
@@ -149,10 +149,10 @@ static void read_reply(int fd) {
             FD_SET(fd, &rd);
             select(fd + 1, &rd, NULL, NULL, NULL);
             if(FD_ISSET(fd, &rd)) {
-                ssize_t eax = recv(fd, buf,
+                ssize_t ret = recv(fd, buf,
                  min_uint(sizeof(buf), reply_size), 0);
-                write(STDOUT_FILENO, buf, eax);
-                reply_size -= eax;
+                write(STDOUT_FILENO, buf, ret);
+                reply_size -= ret;
             }
         }
     }
