@@ -24,7 +24,6 @@ user/rpld.c - User space daemon (filtering, etc.)
 =============================================================================*/
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/time.h> // gettimeofday()
 #include <ctype.h>
 #include <errno.h>
 #include <fcntl.h>
@@ -34,7 +33,6 @@ user/rpld.c - User space daemon (filtering, etc.)
 #include "rpl_stdint.h"
 #include <stdio.h>
 #include <stdlib.h>
-extern int posix_memalign(void **, size_t, size_t);
 #include <string.h>
 #include <syslog.h>
 #include <time.h>
@@ -128,11 +126,11 @@ int main(int argc, const char **argv) {
 
     if(GOpt.verbose) {
         printf("# rpld " TTYRPLD_VERSION "\n");
-        printf(_("This program comes with ABSOLUTELY NO WARRANTY; it is free"
-          " software\n" "and you are welcome to redistribute it under certain"
-          " conditions; for\n" "details see the \"LICENSE\" file which should"
-          " have come with this program.\n")
-        );
+        printf(_(
+            "This program comes with ABSOLUTELY NO WARRANTY; it is free software and you\n"
+            "you are welcome to redistribute it under certain conditions; for details see\n"
+            "the \"LICENSE.GPL2\" file which should have come with this program.\n"
+        ));
         printf("\n");
     }
 
@@ -173,17 +171,10 @@ static void mainloop(int fd) {
         if((ret = read(fd, &packet, sizeof(struct rpldev_packet))) <
          (ssize_t)sizeof(struct rpldev_packet)) {
             struct stat sb;
-#if defined(__OpenBSD__) || defined(__NetBSD__)
-            int e = errno;
-#endif
             fstat(fd, &sb);
-            if(!S_ISREG(sb.st_mode)) {
-#if defined(__OpenBSD__) || defined(__NetBSD__)
-                if(e == EINTR) continue;
-#endif
+            if(!S_ISREG(sb.st_mode))
                 fprintf(stderr, _("\n" "Short read: %ld bytes only. "
                  "Error %d: %s\n"), (long)ret, errno, strerror(errno));
-            }
             Opt._running = 0;
             break;
         }
